@@ -1,29 +1,17 @@
-// GUI of MediaInfo
-// Copyright (C) 2011-2012 MediaArea.net SARL, Info@MediaArea.net
-//
-// This program is free software: you can redistribute it and/or modify it
-// under the terms of the GNU Library General Public License as published by
-// the Free Software Foundation, either version 2 of the License, or
-// (at your option) any later version.
-//
-// This program is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-// GNU Library General Public License for more details.
-//
-// You should have received a copy of the GNU Library General Public License
-// along with this program. If not, see <http://www.gnu.org/licenses/>.
-//
-//+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
-//+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
+/*  Copyright (c) MediaArea.net SARL. All Rights Reserved.
+ *
+ *  Use of this source code is governed by a BSD-style license that can
+ *  be found in the License.html file in the root of the source tree.
+ */
 
 #include "custom.h"
+#include "Common/Core.h"
 
 int Custom::indexDefault = 0;
 QVector<Custom*> Custom::customs = QVector<Custom*>();
 QStringList Custom::names = QStringList();
 
-Custom::Custom(QString name)
+Custom::Custom(const QString& name)
 {
     this->name = name;
     this->page = "%Files%";
@@ -135,18 +123,18 @@ QString Custom::getStream(int stream) {
     return streams[stream];
 }
 
-void Custom::setName(QString n) {
+void Custom::setName(const QString& n) {
     name = n;
 }
-void Custom::setPage(QString p) {
+void Custom::setPage(const QString& p) {
     page = p;
 }
 
-void Custom::setFile(QString f) {
+void Custom::setFile(const QString& f) {
     file = f;
 }
 
-void Custom::setStream(int stream, QString s) {
+void Custom::setStream(int stream, const QString& s) {
     if(stream<streams.size())
        streams[stream] = s;
 }
